pub struct LoadParams {
pub check_network: Option<Network>,
pub check_genesis_hash: Option<Arc<BlockHash>>,
pub lookahead: u32,
pub use_spk_cache: bool,
}Expand description
Parameters for Wallet loading.
Fields
check_network: Option<Network>Checks that the given network matches the one loaded from persistence.
check_genesis_hash: Option<Arc<BlockHash>>Checks that the given genesis_hash matches the one loaded from persistence.
lookahead: u32Use a custom lookahead value.
use_spk_cache: boolUse a persistent cache of indexed script pubkeys (SPKs).